@@ -17,17 +17,18 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import base64
 import logging
 import os
 import json
 import string
 import shutil
-import time
 import xapian
+import time
 
 from gi.repository import GObject
 
+from softwarecenter.utils import utf8
+
 # py3 compat
 try:
     from configparser import RawConfigParser, NoOptionError
@@ -87,8 +88,8 @@ CF = "/var/lib/apt-xapian-index/cataloged_times.p"
 if os.path.exists(CF):
     try:
         cataloged_times = pickle.load(open(CF))
-    except EOFError as e:
-        LOG.warn("failed to read %s (%s" % (CF, e))
+    except Exception as e:
+        LOG.warn("failed to load %s: %s" % (CF, e))
 del CF
 
 # Enable Xapian's CJK tokenizer (see LP: #745243)
@@ -142,6 +143,7 @@ class SoftwareCenterAgentParser(AppInfoParserBase):
                 'Deb-Line'   : 'deb_line',
                 'Signing-Key-Id' : 'signing_key_id',
                 'License'    : 'license',
+                'Date-Published' : 'date_published',
                 'Purchased-Date' : 'purchase_date',
                 'License-Key' : 'license_key',
                 'License-Key-Path' : 'license_key_path',
@@ -176,9 +178,9 @@ class SoftwareCenterAgentParser(AppInfoParserBase):
         return getattr(self.sca_entry, self._apply_mapping(key))
     def get_desktop_categories(self):
         try:
-            return ['SC_CATEGORY'] + self.sca_entry.department
+            return ['DEPARTMENT:' + self.sca_entry.department[-1]] + self._get_desktop_list("Categories")
         except:
-            return []
+            return self._get_desktop_list("Categories")
     def has_option_desktop(self, key):
         return (key in self.STATIC_DATA or
                 hasattr(self.sca_entry, self._apply_mapping(key)))
@@ -491,7 +493,7 @@ def add_from_purchased_but_needs_reinstall_data(purchased_but_may_need_reinstall
             # WARNING: item.name needs to be different than
             #          the item.name in the DB otherwise the DB
             #          gets confused about (appname, pkgname) duplication
-            item.name = _("%s (already purchased)") % item.name
+            item.name = utf8(_("%s (already purchased)")) % utf8(item.name)
             parser = SoftwareCenterAgentParser(item)
             index_app_info_from_parser(parser, db_purchased, cache)
         except Exception as e:
@@ -541,22 +543,6 @@ def update_from_software_center_agent(db, cache, ignore_cache=False,
         try:
             # magic channel
             entry.channel = AVAILABLE_FOR_PURCHASE_MAGIC_CHANNEL_NAME
-            # icon is transmited inline
-            if hasattr(entry, "icon_data") and entry.icon_data:
-                icondata = base64.b64decode(entry.icon_data)
-            elif hasattr(entry, "icon_64_data") and entry.icon_64_data:
-                # workaround for scagent bug #740112
-                icondata = base64.b64decode(entry.icon_64_data)
-            else:
-                icondata = ""
-            # write it if we have data
-            if icondata:
-            # the iconcache gets mightly confused if there is a "." in the name
-                iconname = "sc-agent-%s" % entry.package_name.replace(".", "__")
-                open(os.path.join(
-                        softwarecenter.paths.SOFTWARE_CENTER_ICON_CACHE_DIR,
-                        "%s.png" % iconname),"w").write(icondata)
-                entry.icon = iconname
             # now the normal parser
             parser = SoftwareCenterAgentParser(entry)
             index_app_info_from_parser(parser, db, cache)
@@ -632,11 +618,7 @@ def index_app_info_from_parser(parser, db, cache):
         if "catalogedtime" in axi_values:
             if pkgname in cataloged_times:
                 doc.add_value(axi_values["catalogedtime"], 
-                              xapian.sortable_serialise(cataloged_times[pkgname]))
-            else:
-                # also catalog apps not found in axi (e.g. for-purchase apps)
-                doc.add_value(axi_values["catalogedtime"], 
-                              xapian.sortable_serialise(time.time()))
+                          xapian.sortable_serialise(cataloged_times[pkgname]))
         # pocket (main, restricted, ...)
         if parser.has_option_desktop("X-AppInstall-Section"):
             archive_section = parser.get_desktop("X-AppInstall-Section")
@@ -659,6 +641,23 @@ def index_app_info_from_parser(parser, db, cache):
         if parser.has_option_desktop("X-AppInstall-License"):
             license = parser.get_desktop("X-AppInstall-License")
             doc.add_value(XapianValues.LICENSE, license)
+        # date published
+        if parser.has_option_desktop("X-AppInstall-Date-Published"):
+            date_published = parser.get_desktop("X-AppInstall-Date-Published")
+            # strip the subseconds from the end of the published date string
+            date_published = str(date_published).split(".")[0]
+            doc.add_value(XapianValues.DATE_PUBLISHED,
+                          date_published)
+            # we use the date published value for the cataloged time as well
+            if "catalogedtime" in axi_values:
+                LOG.debug(
+                        ("pkgname: %s, date_published cataloged time is: %s" %
+                             (pkgname, parser.get_desktop("date_published"))))
+                date_published_sec = time.mktime(
+                                        time.strptime(date_published,
+                                                      "%Y-%m-%d  %H:%M:%S"))
+                doc.add_value(axi_values["catalogedtime"], 
+                              xapian.sortable_serialise(date_published_sec))
         # purchased date
         if parser.has_option_desktop("X-AppInstall-Purchased-Date"):
             date = parser.get_desktop("X-AppInstall-Purchased-Date")
@@ -696,7 +695,10 @@ def index_app_info_from_parser(parser, db, cache):
             url = parser.get_desktop("X-AppInstall-Icon-Url")
             doc.add_value(XapianValues.ICON_URL, url)
             if not parser.has_option_desktop("X-AppInstall-Icon"):
-                doc.add_value(XapianValues.ICON, os.path.basename(url))
+                # prefix pkgname to avoid name clashes
+                doc.add_value(XapianValues.ICON, "%s-icon-%s" % (
+                        pkgname, os.path.basename(url)))
+
         # price (pay stuff)
         if parser.has_option_desktop("X-AppInstall-Price"):
             price = parser.get_desktop("X-AppInstall-Price")
