@@ -103,9 +103,6 @@ class AvailablePane(SoftwarePane):
         while Gtk.events_pending():
             Gtk.main_iteration()
 
-        # open the cache since we are initializing the UI for the first time    
-        GObject.idle_add(self.cache.open)
-        
         SoftwarePane.init_view(self)
         # set the AppTreeView model, available pane uses list models
         liststore = AppListStore(self.db, self.cache, self.icons)
@@ -117,6 +114,9 @@ class AvailablePane(SoftwarePane):
         # setup purchase stuff
         self.app_details_view.connect("purchase-requested",
                                       self.on_purchase_requested)
+        liststore.connect(
+            "needs-refresh", lambda helper, pkgname: self.app_view.queue_draw())
+
         # purchase view
         self.purchase_view = PurchaseView()
         self.purchase_view.connect("purchase-succeeded", self.on_purchase_succeeded)
@@ -421,8 +421,8 @@ class AvailablePane(SoftwarePane):
 
         # yeah for special cases - as discussed on irc, mpt
         # wants this to return to the category screen *if*
-        # we are searching but we are not in any category
-        if not self.state.category and not new_text:
+        # we are searching but we are not in any category or channel
+        if not self.state.category and not self.state.channel and not new_text:
             # category activate will clear search etc
             self.state.reset()
             vm.display_page(self,
