@@ -42,7 +42,8 @@ from softwarecenter.utils import (ExecutionTime,
                                   convert_desktop_file_to_installed_location,
                                   get_file_path_from_iconname,
                                   wait_for_apt_cache_ready,
-                                  utf8
+                                  utf8,
+                                  get_exec_line_from_desktop
                                   )
 
 from softwarecenter.ui.gtk3.session.viewmanager import get_viewmanager
@@ -55,8 +56,6 @@ from softwarecenter.ui.gtk3.views.appdetailsview_gtk import (
                                                 AppDetailsViewGtk as
                                                 AppDetailsView)
 
-from softwarecenter.utils import is_no_display_desktop_file
-
 from basepane import BasePane
 
 LOG = logging.getLogger(__name__)
@@ -129,12 +128,12 @@ class DisplayState(object):
         return object.__setattr__(self, name, val)
 
     def __str__(self):
-        s = unicode('%s %s "%s" %s %s', 'utf8').encode('utf8') % \
-                                 (self.category,
-                                  self.subcategory,
-                                  self.search_term,
-                                  self.application,
-                                  self.channel,)
+        s = utf8('%s %s "%s" %s %s') % \
+                                  (self.category,
+                                   self.subcategory,
+                                   self.search_term,
+                                   self.application,
+                                   self.channel)
         return s
 
     def copy(self):
@@ -259,9 +258,7 @@ class SoftwarePane(Gtk.VBox, BasePane):
 
         self.app_view = AppView(self.db, self.cache,
                                 self.icons, self.show_ratings)
-        self.app_view.sort_methods_combobox.connect(
-                    "changed",
-                    self.on_app_view_sort_method_changed)
+        self.app_view.connect("sort-method-changed", self.on_app_view_sort_method_changed)
 
         self.init_atk_name(self.app_view, "app_view")
         self.box_app_list.pack_start(self.app_view, True, True, 0)
@@ -395,10 +392,13 @@ class SoftwarePane(Gtk.VBox, BasePane):
         # we only show the prompt for apps with a desktop file
         if not appdetails.desktop_file:
             return
-        # do not add apps without a exec line (like wine, see #848437)
+        # do not add apps that have no Exec entry in their desktop file
+        # (e.g. wine, see LP: #848437 or ubuntu-restricted-extras,
+        # see LP: #913756)
         if (os.path.exists(appdetails.desktop_file) and
-            is_no_display_desktop_file(appdetails.desktop_file)):
-                return
+            not get_exec_line_from_desktop(appdetails.desktop_file)):
+            return
+            
         self.action_bar.add_button(ActionButtons.CANCEL_ADD_TO_LAUNCHER,
                                     _("Not Now"), 
                                     self.on_cancel_add_to_launcher, 
@@ -414,20 +414,17 @@ class SoftwarePane(Gtk.VBox, BasePane):
 
     def on_query_complete(self, enquirer):
         self.emit("app-list-changed", len(enquirer.matches))
-        sort_by_relevance = (self._is_in_search_mode() and
-                             not self.app_view.user_defined_sort_method)
-        
         self.app_view.display_matches(enquirer.matches,
-                                      sort_by_relevance)
+                                      self._is_in_search_mode())
         self.hide_appview_spinner()
         return
 
-    def on_app_view_sort_method_changed(self, combo):
-        if self.app_view.get_sort_mode() == self.enquirer.sortmode:
+    def on_app_view_sort_method_changed(self, app_view, combo):
+        if app_view.get_sort_mode() == self.enquirer.sortmode:
             return
 
         self.show_appview_spinner()
-        self.app_view.clear_model()
+        app_view.clear_model()
         query = self.get_query()
         self._refresh_apps_with_apt_cache(query)
         return
