@@ -1161,7 +1161,7 @@ class AppDetailsViewGtk(Viewport, AppDetailsViewBase):
         if app_details.version:
             version = '%s %s' % (app_details.pkgname, app_details.version)
         else:
-            version = _("%s (unknown version)") % app_details.pkgname
+            version = utf8(_("%s (unknown version)")) % utf8(app_details.pkgname)
         if app_details.license:
             license = app_details.license
         else:
@@ -1410,6 +1410,8 @@ class AppDetailsViewGtk(Viewport, AppDetailsViewBase):
         if same_app and not force:
             self._update_minimal(self.app_details)
         else:
+            # reset reviews_page
+            self._reviews_server_page = 1
             # update all (but skip the addons calculation if this is a
             # DebFileApplication as this is not useful for this case and it
             # increases the view load time dramatically)
