@@ -20,12 +20,12 @@
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import WebKit as webkit
 import logging
 import os
 import json
 import sys
 import urllib
-from gi.repository import WebKit as webkit
 
 from gettext import gettext as _
 
@@ -34,6 +34,16 @@ from softwarecenter.utils import get_language
 
 LOG = logging.getLogger(__name__)
 
+# enable certificates validation in webkit views unless specified otherwise
+if not "SOFTWARE_CENTER_FORCE_DISABLE_CERTS_CHECK" in os.environ:
+    session = webkit.get_default_session()
+    session.set_property("ssl-ca-file", "/etc/ssl/certs/ca-certificates.crt")
+else:
+    # WARN the user!! Do not remove this
+    LOG.warning("SOFTWARE_CENTER_FORCE_DISABLE_CERTS_CHECK " +
+                "has been specified, all purchase transactions " + 
+                "are now INSECURE and UNENCRYPTED!!")
+
 class LocaleAwareWebView(webkit.WebView):
     
     def __init__(self):
@@ -174,7 +184,13 @@ h1 {
         
     def _on_create_web_view(self, view, frame):
         win = Gtk.Window()
-        win.set_size_request(400, 400)
+        win.set_size_request(500, 400)
+        # set transient parent
+        parent = self
+        while parent.get_parent():
+            parent = parent.get_parent()
+        win.set_transient_for(parent)
+        # and add the webkit view
         wk = ScrolledWebkitWindow()
         wk.webkit.connect("close-web-view", self._on_close_web_view)
         win.add(wk)
