@@ -1,13 +1,8 @@
 #!/usr/bin/python
 
-import glib
-import os
 import sys
-import time
 import unittest
 
-from mock import Mock
-
 sys.path.insert(0,"../")
 from softwarecenter.distro.Ubuntu import Ubuntu
 
@@ -50,7 +45,8 @@ class TestDistroUbuntu(unittest.TestCase):
         mock_cache = MockCache("http://ppa.launchpad.net/mvo/ppa/ubuntu")
         pkgname = "pkg"
         iconname = "iconfilename"
-        icon_url = self.distro.get_downloadable_icon_url(mock_cache, pkgname, iconname)
+        pkg_uri = mock_cache[pkgname].candidate.uri
+        icon_url = self.distro.get_downloadable_icon_url(pkg_uri, iconname)
         self.assertEqual(icon_url,
                          "http://ppa.launchpad.net/mvo/meta/ppa/iconfilename")
 
