@@ -1,32 +1,33 @@
 #!/usr/bin/python
 
+import os
 import sys
 import unittest
 sys.path.insert(0,"../")
 
-from softwarecenter.enums import *
-from softwarecenter.utils import *
 from softwarecenter.paths import XAPIAN_BASE_PATH
-
-from softwarecenter.apt.aptcache import AptCache
+from softwarecenter.ui.gtk3.gmenusearch import GMenuSearcher
+from softwarecenter.db.pkginfo import get_pkg_info
 from softwarecenter.db.database import StoreDatabase
-from softwarecenter.db.application import Application, AppDetails
+from softwarecenter.db.application import Application
 
-import gmenu
 
 class TestWhereIsit(unittest.TestCase):
     """ tests the "where is it in the menu" code """
 
     def setUp(self):
-        datadir = "../data"
-        cache = AptCache()
+        cache = get_pkg_info()
         cache.open()
         xapian_base_path = XAPIAN_BASE_PATH
         pathname = os.path.join(xapian_base_path, "xapian")
         self.db = StoreDatabase(pathname, cache)
         self.db.open()
 
-    def test_where_is_it_in_system(self):
+    # mvo: disabled for now (2011-06-06) because the new gnome-panel
+    #      does not have "System" anymore and its not clear to me yet
+    #      where those items will appear. Once that is settled it
+    #      should be re-enabled
+    def disabled_for_now_test_where_is_it_in_system(self):
         app = Application("Hardware Drivers", "jockey-gtk")
         details = app.get_details(self.db)
         self.assertEqual(details.desktop_file, 
@@ -34,7 +35,7 @@ class TestWhereIsit(unittest.TestCase):
         # search the settings menu
         searcher = GMenuSearcher()
         found = searcher.get_main_menu_path(details.desktop_file)
-        self.assertEqual(found[0].get_name(), "System")
+        self.assertEqual(found[0].get_name(), "Desktop")
         self.assertEqual(found[0].get_icon(), "preferences-other")
         self.assertEqual(found[1].get_name(), "Administration")
         self.assertEqual(found[1].get_icon(), "preferences-system")
@@ -43,31 +44,35 @@ class TestWhereIsit(unittest.TestCase):
         app = Application("Calculator", "gcalctool")
         details = app.get_details(self.db)
         self.assertEqual(details.desktop_file, 
-                         "/usr/share/app-install/desktop/gcalctool.desktop")
+                         "/usr/share/app-install/desktop/gcalctool:gcalctool.desktop")
         # search the settings menu
         searcher = GMenuSearcher()
         found = searcher.get_main_menu_path(
             details.desktop_file,
             [os.path.abspath("./data/fake-applications.menu")])
         self.assertEqual(found[0].get_name(), "Applications")
-        self.assertEqual(found[0].get_icon(), "applications-other")
+        self.assertEqual(found[0].get_icon().get_names()[0], 
+                         "applications-other")
         self.assertEqual(found[1].get_name(), "Accessories")
-        self.assertEqual(found[1].get_icon(), "applications-utilities")
+        self.assertEqual(found[1].get_icon().get_names()[0], 
+                         "applications-utilities")
     
     def test_where_is_it_kde4(self):
         app = Application("", "ark")
         details = app.get_details(self.db)
         self.assertEqual(details.desktop_file, 
-                         "/usr/share/app-install/desktop/kde4___ark.desktop")
+                         "/usr/share/app-install/desktop/ark:kde4__ark.desktop")
         # search the settings menu
         searcher = GMenuSearcher()
         found = searcher.get_main_menu_path(
             details.desktop_file,
             [os.path.abspath("./data/fake-applications.menu")])
         self.assertEqual(found[0].get_name(), "Applications")
-        self.assertEqual(found[0].get_icon(), "applications-other")
+        self.assertEqual(found[0].get_icon().get_names()[0], 
+                         "applications-other")
         self.assertEqual(found[1].get_name(), "Accessories")
-        self.assertEqual(found[1].get_icon(), "applications-utilities")
+        self.assertEqual(found[1].get_icon().get_names()[0], 
+                         "applications-utilities")
         
 
 if __name__ == "__main__":
